import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.awt.*;

public class AnalogIn extends Pin implements ChangeListener {

	private final JSlider slider = new JSlider();

	public AnalogIn (final int pin) {
		this.id = pin;

		setBackground(BORDER_INVALID);

		slider.addChangeListener(this);
		slider.setOpaque(false);

		slider.setOrientation(JSlider.VERTICAL);
		slider.setMinimum(0);
		slider.setMaximum(1023);
		slider.setValue(512);

		setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.anchor = GridBagConstraints.NORTH;
		c.fill = GridBagConstraints.VERTICAL;
		c.weightx = 0.5;
		c.weighty = 0.99;
		c.gridx = 0;
		c.gridy = 0;
		add(slider, c);
		final JLabel label = new JLabel("" + pin);
		label.setFont(new Font(label.getFont().getName(), label.getFont().getStyle(), 8));
		c.gridy = 1;
		c.weighty = 0.01;
		add(label, c);
	}

	public void setMode (final MODE mode) {
		error("Don't set mode for the analog input pin " + id);
	}

	public void setAD (final AD ad) {
		error("Don't set A/D-mode for the analog input pin " + id);
	}

	public int getFeatures () {
		return ANALOG_IN;
	}

	public void hasBeenReadFrom () {
		setBackground(BORDER_INPUT);
	}

	public void setLevel (final Container Container, final int level) {
		error("Don't set a level for the analog input pin " + id);
	}

	public void setValue (final Container Container, final int value) {
		if (value == Core.LEVEL_INVALID)
			error("INVALID value for the analog pin " + id);
		else {
			slider.setValue(value);
		}
	}

	public void stateChanged (ChangeEvent e) {
		((JSlider) e.getSource()).setToolTipText("" + ((JSlider) e.getSource()).getValue());
		if (pinChangeListener != null)// Happens when initialized
			pinChangeListener.setValue(this, ((JSlider) e.getSource()).getValue());
	}
}
