import javax.swing.*;
import java.awt.*;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLConnection;

public class BackgroundImage extends JLabel {
	public BackgroundImage (final String imageName) {
		setIcon(new ImageIcon(getByteArrayFromFile(imageName)));
	}

	// Scale...
	public void paintComponent (Graphics g) {
		super.paintComponent(g);
		g.drawImage(((ImageIcon) getIcon()).getImage(), 0, 0, getWidth(), getHeight(), null);
	}

	@Override
	public Dimension getMinimumSize () {
		return new Dimension(30, 30);
	}

	private byte[] getByteArrayFromFile (final String filename) {
		final BufferedInputStream r = new BufferedInputStream(getFileStream(filename, true));
		try {
			byte[] b = new byte[r.available()];
			//noinspection ResultOfMethodCallIgnored
			r.read(b);
			return b;
		}
		catch (IOException e) {
			Core.error("getByteArrayFromFile(" + filename + "): " + e.getMessage());
			return null;
		}
	}

	private InputStream getFileStream (final String filename, boolean reportError) {
		InputStream r = null;
		try {
			final URLConnection uc = this.getClass().getClassLoader().getResource(filename).openConnection();
			uc.setUseCaches(false);
			uc.setDoInput(true);
			r = uc.getInputStream();
		} catch (Exception e) {
			Core.error(e.getStackTrace()[4] + ": " + e.getMessage());
		}
		return r;
	}
}
