import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.awt.*;

public class DigitalIO extends Pin implements ChangeListener {
	private final JCheckBox checkbox = new JCheckBox();

	public DigitalIO (final int pin) {
		this.id = pin;

		setBackground(BORDER_INVALID);

		checkbox.setEnabled(false);
		checkbox.addChangeListener(this);
		checkbox.setOpaque(false);

		setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.anchor = GridBagConstraints.NORTH;
		c.weightx = 0.5;
		c.weighty = 0.01;
		c.gridx = 0;
		c.gridy = 0;
		final JLabel label = new JLabel("" + pin);
		label.setFont(new Font(label.getFont().getName(), label.getFont().getStyle(), 8));
		add(label, c);
		c.gridy = 1;
		add(checkbox, c);
		c.gridy = 1;
		JPanel jp = new JPanel();
		jp.setOpaque(false);
		c.weighty = 0.98;
		c.gridy = 2;
		add(jp, c);
	}

	public void setMode (final MODE mode) {
		switch (mode) {
			case INPUT:
				checkbox.setEnabled(true);
				setBackground(BORDER_INPUT);
				break;
			case OUTPUT:
				checkbox.setEnabled(false);
				setBackground(BORDER_OUTPUT);
				break;
			case INVALID:
				error("INVALID mode for pin " + id);
		}
	}

	public void setAD (final AD ad) {
		error("Don't set A/D-mode for the digital input pin " + id);
	}

	public int getFeatures () {
		return DIGITAL_IN | DIGITAL_OUT;
	}

	// Only needed for analog input devices, since they're always in 'input'-mode...
	public void hasBeenReadFrom () {
	}

	public void setLevel (final Container Container, final int level) {
		if (level == Core.LEVEL_INVALID)
			error("INVALID level for the digital pin " + id);
		else {
			checkbox.setSelected(level == Core.HIGH);
		}
	}

	public void setValue (final Container Container, final int value) {
		error("Don't set a value for the digital input pin " + id);
	}

	public void stateChanged (ChangeEvent e) {
		pinChangeListener.setLevel(this, ((JCheckBox) e.getSource()).isSelected() ? Core.HIGH : Core.LOW);
	}
}
