import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.awt.*;

public class DigitalIO_PWMOut extends Pin implements ChangeListener {
	private AD ad;

	private final JCheckBox checkbox = new JCheckBox();
	private final JProgressBar bar = new JProgressBar(JProgressBar.VERTICAL, 0, 255);

	public DigitalIO_PWMOut (final int pin) {
		this.id = pin;

		setBackground(BORDER_INVALID);

		checkbox.setEnabled(false);
		checkbox.addChangeListener(this);
		checkbox.setOpaque(false);

		setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.anchor = GridBagConstraints.NORTH;
		c.fill = GridBagConstraints.VERTICAL;
		c.weightx = 0.5;
		c.weighty = 0.01;
		c.gridx = 0;
		c.gridy = 0;
		final JLabel label = new JLabel("" + pin);
		label.setFont(new Font(label.getFont().getName(), label.getFont().getStyle(), 8));
		add(label, c);
		c.gridy = 1;
		add(checkbox, c);
		c.weighty = 0.99;
		c.gridy = 2;
		add(bar, c);
	}

	public void setMode (final MODE mode) {
		switch (mode) {
			case INPUT:
				setBackground(BORDER_INPUT);
				checkbox.setEnabled(true);
				if (ad == AD.INVALID)
					error("INVALID A/D-mode while setting mode for pin " + id);
				break;
			case OUTPUT:
				setBackground(BORDER_OUTPUT);
				checkbox.setEnabled(false);
				break;
			case INVALID:
				error("INVALID mode for pin " + id);
		}
	}

	public void setAD (final AD ad) {
		this.ad = ad;
		switch (ad) {
			case ANALOG:
				checkbox.setEnabled(false);
				setBackground(BORDER_INVALID);
				break;
			case DIGITAL:
				checkbox.setEnabled(true);
				setBackground(BORDER_INVALID);
				break;
			case INVALID:
				error("INVALID A/D-mode for pin " + id);
		}
	}

	public int getFeatures () {
		return DIGITAL_IN | DIGITAL_OUT | ANALOG_OUT;
	}

	// Only needed for analog input devices, since they're always in 'input'-mode...
	public void hasBeenReadFrom () {
	}

	public void setLevel (final Container Container, final int level) {
		if (level == Core.LEVEL_INVALID)
			error("INVALID level for pin " + id);
		else {
			setToolTipText("" + level);
			setBackground(BORDER_OUTPUT);
			checkbox.setSelected(level == Core.HIGH);
			bar.setValue(level == Core.HIGH ? bar.getMaximum() : bar.getMinimum());
		}
	}

	public void setValue (final Container Container, final int value) {
		if (value == -1)
			error("INVALID value for pin " + id);
		else {
			setToolTipText("" + value);
			setBackground(BORDER_OUTPUT);
			checkbox.setSelected(false);
			bar.setValue(value);
		}
	}

	public void stateChanged (ChangeEvent e) {
		pinChangeListener.setLevel(this, ((JCheckBox) e.getSource()).isSelected() ? Core.HIGH : Core.LOW);
	}
}
