import java.io.IOException;

enum ASCIIMODE { // For Serial
	DEC, HEX, OCT, BIN, BYTE
}

public class Serial {
	private static long baud = 0;

	public static void begin (final long datarate) {
		baud = datarate; // Initialize!
	}

	public static int available () {
		if (baud == 0)
			error("Serial not yet initialized!");
		try {
			return System.in.available();
		} catch (IOException e) {
			e.printStackTrace();
			return 0;
		}
	}

	// '-1' if nothing...
	public static int read () {
		if (baud == 0)
			error("Serial not yet initialized!");
		try {
			return System.in.read();
		} catch (IOException e) {
			e.printStackTrace();
			return -1;
		}
	}

	// Flushes the in/out buffers!
	public static void flush () {
		if (baud == 0)
			error("Serial not yet initialized!");
		// Todo
	}

	public static void print (final int data) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.print(data);
	}

	public static void print (final int data, final ASCIIMODE mode) {
		if (baud == 0)
			error("Serial not yet initialized!");
		switch (mode) {
			case BIN:
				System.out.print(Integer.toBinaryString(data));
				break;
			case BYTE:
				System.out.print((byte) data);
				break;
			case DEC:
				System.out.print(data);
				break;
			case HEX:
				System.out.print(Integer.toHexString(data));
				break;
			case OCT:
				System.out.print(Integer.toOctalString(data));
				break;
		}
	}

	public static void print (final String data) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.print(data);
	}

	public static void println (final int data) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.println("" + data);
	}

	public static void println (final int data, final ASCIIMODE mode) {
		if (baud == 0)
			error("Serial not yet initialized!");
		switch (mode) {
			case BIN:
				System.out.println(Integer.toBinaryString(data));
				break;
			case BYTE:
				System.out.println((byte) data);
				break;
			case DEC:
				System.out.println(data);
				break;
			case HEX:
				System.out.println(Integer.toHexString(data));
				break;
			case OCT:
				System.out.println(Integer.toOctalString(data));
				break;
		}
	}

	public static void println (final String data) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.println(data);
	}

	public static void println () {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.println();
	}

	public static void write (final byte val) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.write(val);
	}

	public static void write (final String str) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.write(str.getBytes(), 0, str.length());
	}

	public static void write (final byte[] buf, final int len) {
		if (baud == 0)
			error("Serial not yet initialized!");
		System.out.write(buf, 0, len);
	}

	private static void error (final String string) {
		System.err.println(
			(System.currentTimeMillis() % 1000) + " " +
				Thread.currentThread().getStackTrace()[2].getClassName() + "(" +
				Thread.currentThread().getStackTrace()[2].getLineNumber() + "): " +
				string
		);
	}
}
